﻿namespace FogIndex

open System
open System.Windows
open System.Windows.Controls

/// Table layout panel type extends XAML based Grid type for easier use from code
type TableLayout (widths:string seq,heights:string seq) =
    inherit Grid ()   
    let star = GridUnitType.Star
    /// Converts grid length string to GridLength instance
    let ParseLength (s:string) =
        match s.Length, s.EndsWith("*") with
        | 0, _ -> GridLength()
        | n, false -> GridLength(Double.Parse(s))
        | 1, true -> GridLength(1.0, star)
        | n, true -> GridLength(Double.Parse(s.Substring(0, n-1)), star)
    let ToCol len = ColumnDefinition(Width=len)
    let ToRow len = RowDefinition(Height=len)
    do  widths |> Seq.iter (ParseLength >> ToCol >> base.ColumnDefinitions.Add)
    do  heights |> Seq.iter (ParseLength >> ToRow >> base.RowDefinitions.Add)
    /// Adds child to layout, automatically setting grid column and row values
    member this.AddChild (child:#FrameworkElement) =
        let span = match this.ColumnDefinitions.Count with 0 -> 1 | n -> n
        let index = this.Children.Count 
        child |> this.Children.Add |> ignore        
        Grid.SetColumn(child, index % span)
        Grid.SetRow(child, index / span)
    static member ( + ) (this:TableLayout, child:#FrameworkElement) = 
        this.AddChild child; this

