﻿namespace FogIndex

open System

[<AutoOpen>]
module Text =
    let getSentences (text:string) =
        text.Split([|'.';'!';'?'|],StringSplitOptions.RemoveEmptyEntries)
        |> Array.map (fun sentence -> sentence.Trim())
        |> Array.filter (fun sentence -> sentence.Length > 0)

    let getWords (text:string) =
        text.Split([|' ';'-';',';'\t';'\r';'\n'|],StringSplitOptions.RemoveEmptyEntries)

    let fold (f:'a -> char -> 'a) (acc:'a) (s:string) =
        let mutable acc = acc
        for c in s do acc <- f acc c
        acc

    let isVowel (c:char) = ("aeiou".IndexOf(c)) >= 0

    let countSyllables (word:string) =
        let word = word.ToLower()
        let dipthongs = ["oo";"ou";"ie";"oi";"ea";"ee";"eu";"ai";"ua";"ue";"au";"io"]
        let word =
            dipthongs |> List.fold (fun (acc:string) d -> acc.Replace(d,d.[0].ToString())) word
        let vowelCount = 
            word 
            |> fold (fun count c -> count + (match isVowel c with true -> 1 | false -> 0)) 0
        if word.EndsWith "e" then vowelCount - 1 else vowelCount
